@@ -15,7 +15,7 @@ if TYPE_CHECKING:
     from neoscore.core.layout_controllers import NewLine
 
 
-class render_cached_property(functools.cached_property):
+class render_cached_property(functools.cached_property):  # noqa
 
     """A property annotation for fields which can be cached at render time.
 
@@ -42,7 +42,7 @@ class render_cached_property(functools.cached_property):
         self.attrname = None
         self.__doc__ = func.__doc__
 
-    def __get__(self, obj, cls):
+    def __get__(self, obj, cls):  # noqa
         if obj is None:
             return self
         result = self.func(obj)
@@ -50,9 +50,12 @@ class render_cached_property(functools.cached_property):
             return result
         property_name = self.func.__name__
         value = obj.__dict__[property_name] = result
-        obj._render_cached_properties.add(property_name)
+        obj._render_cached_properties.add(property_name)  # noqa
         return value
 
+    def __set__(self, obj, val):
+        raise AttributeError(f"can't set attribute '{self.func.__name__}'")
+
 
 class PositionedObject:
     """An object positioned in the scene
@@ -90,6 +93,7 @@ class PositionedObject:
         self._parent = PositionedObject._resolve_parent(parent)
         self._set_parent_and_register_self(parent)
         self._render_cached_properties: set[str] = set()
+        self._currently_rendering = False
         self._interfaces = []
 
     @property
@@ -155,9 +159,9 @@ class PositionedObject:
 
     @property
     def descendants(self) -> Iterator[PositionedObject]:
-        """All of the objects in the children subtree.
+        """All the objects in the children subtree.
 
-        This recursively searches all of the object's children
+        This recursively searches all the object's children
         (and their children, etc.) and provides an iterator over them.
 
         The current implementation performs a simple recursive DFS over
@@ -221,7 +225,7 @@ class PositionedObject:
         """
         ancestor = self.parent
         while True:
-            yield (ancestor)
+            yield ancestor
             if not hasattr(ancestor, "parent"):
                 # Document root found
                 break
@@ -270,7 +274,7 @@ class PositionedObject:
         This calculates the position in *logical* space, which differs from canvas space
         in that it doesn't account for repositioning of objects inside :obj:`.Flowable`
         containers. For example, this function will return the same relative position
-        for two objects in a ``Flowable`` container whether or not they are separated by
+        for two objects in a ``Flowable`` container whether they are separated by
         a line break.
         """
         # When changing this method be sure to make the equivalent change in `map_x_to`
@@ -394,6 +398,7 @@ class PositionedObject:
         This and other render methods should generally not be called directly.
         """
         # Calculate position within flowable
+        assert self.flowable is not None
         pos_in_flowable = self.flowable.descendant_pos(self)
         first_line_i = self.flowable.last_break_index_at(pos_in_flowable.x)
         first_line = self.flowable.lines[first_line_i]
@@ -447,10 +452,10 @@ class PositionedObject:
     ):
         """Render the entire object.
 
-        This is used to render all objects outside of flowables, as well as those inside
+        This is used to render all objects outside flowables, as well as those inside
         flowables when they fit completely in one line of the flowable.
 
-        By default this is a no-op. Subclasses with with rendered appearances should
+        By default, this is a no-op. Subclasses with rendered appearances should
         override this.
 
         This and other render methods should generally not be called directly.
@@ -468,7 +473,7 @@ class PositionedObject:
         page break. This function should render the beginning portion of the object up
         to the break.
 
-        By default this is a no-op. Subclasses with with rendered appearances should
+        By default, this is a no-op. Subclasses with rendered appearances should
         override this.
 
         This and other render methods should generally not be called directly.
@@ -490,7 +495,7 @@ class PositionedObject:
         two breaks. This function should render the portion of the object
         surrounded by breaks on either side.
 
-        By default this is a no-op. Subclasses with with rendered appearances should
+        By default, this is a no-op. Subclasses with rendered appearances should
         override this.
 
         This and other render methods should generally not be called directly.
@@ -508,7 +513,7 @@ class PositionedObject:
         page break. This function should render the ending portion of an object after a
         break.
 
-        By default this is a no-op. Subclasses with with rendered appearances should
+        By default, this is a no-op. Subclasses with rendered appearances should
         override this.
 
         This and other render methods should generally not be called directly.
